@@ -56,9 +56,11 @@ def main():
     # Add any snapshot topologies to be converted
     topology_files.extend(get_snapshots(args.topology))
 
+    topology_name = name(args.topology, args.name)
+
     # Do the conversion
     for topology in topology_files:
-        do_conversion(topology, args)
+        do_conversion(topology, topology_name, args.output, args.debug)
 
 
 def setup_argparse():
@@ -86,14 +88,20 @@ def setup_argparse():
     return parser
 
 
-def do_conversion(topology_def, args):
+def do_conversion(topology_def, topology_name, output_dir=None, debug=False):
     """
     Convert the topology
 
-    :param dict topology_def: Dict containing topology file and snapshot bool
+    :param dict topology_def: Dict containing topology file and snapshot bool.
+                              For example:
+                              ``{'file': filename, 'snapshot': False}``
+    :param str topology_name: The name of the topology
+    :param str output_dir: The directory in which to output the topology.
+                           (Default: None)
+    :param bool debug: Enable debugging (Default: False)
     """
     # Create a new instance of the the Converter
-    gns3_conv = Converter(topology_def['file'], args.debug)
+    gns3_conv = Converter(topology_def['file'], debug)
     # Read the old topology
     old_top = gns3_conv.read_topology()
     new_top = JSONTopology()
@@ -111,10 +119,10 @@ def do_conversion(topology_def, args):
     new_top.images = gns3_conv.generate_images(topology['artwork']['PIXMAP'])
 
     # Enter topology name
-    new_top.name = name(args)
+    new_top.name = topology_name
 
     # Save the new topology
-    save(args, gns3_conv, new_top, topology_def['snapshot'])
+    save(output_dir, gns3_conv, new_top, topology_def['snapshot'])
 
 
 def topology_abspath(topology):
@@ -159,19 +167,23 @@ def get_snapshots(topology):
     return snapshots
 
 
-def name(args):
+def name(topology_file, topology_name=None):
     """
-    Calculate the name to save the converted topology as
+    Calculate the name to save the converted topology as using either either
+    a specified name or the directory name of the current project
 
+    :param str topology_file: Topology filename
+    :param topology_name: Optional topology name (Default: None)
+    :type topology_name: str or None
     :return: new topology name
     :rtype: str
     """
-    if args.name is not None:
+    if topology_name is not None:
         logging.debug('topology name supplied')
-        topo_name = args.name
+        topo_name = topology_name
     else:
         logging.debug('topology name not supplied')
-        topo_name = os.path.basename(topology_dirname(args.topology))
+        topo_name = os.path.basename(topology_dirname(topology_file))
     return topo_name
 
 
@@ -191,23 +203,20 @@ def snapshot_name(topo_name):
     return snap_name
 
 
-def save(args, converter, json_topology, snapshot):
+def save(output_dir, converter, json_topology, snapshot):
     """
     Save the converted topology
 
-    :param args: Program arguments
+    :param str output_dir: Output Directory
     :param Converter converter: Converter instance
     :param JSONTopology json_topology: JSON topology layout
-    :param bool snapshot: Snapshot Boolean
+    :param bool snapshot: Is this a snapshot?
     """
     try:
-        config_err = False
-        image_err = False
-
         old_topology_dir = topology_dirname(converter.topology)
 
-        if args.output:
-            output_dir = os.path.abspath(args.output)
+        if output_dir:
+            output_dir = os.path.abspath(output_dir)
         else:
             output_dir = os.getcwd()
 
@@ -226,51 +235,17 @@ def save(args, converter, json_topology, snapshot):
             os.makedirs(output_dir)
 
         # Move the dynamips config files to the new topology folder
-        if len(converter.configs) > 0:
-            dynamips_config_dir = os.path.join(topology_files_dir, 'dynamips',
-                                               'configs')
-            os.makedirs(dynamips_config_dir)
-            for config in converter.configs:
-                old_config_file = os.path.join(old_topology_dir, config['old'])
-                new_config_file = os.path.join(dynamips_config_dir,
-                                               os.path.basename(config['new']))
-                if os.path.isfile(old_config_file):
-                    # Copy and rename the config
-                    shutil.copy(old_config_file, new_config_file)
-                else:
-                    config_err = True
-                    logging.error('Unable to find %s' % config['old'])
+        config_err = copy_configs(converter.configs, old_topology_dir,
+                                  topology_files_dir)
 
-        # Move the image files to the new topology folder if applicable
-        if len(converter.images) > 0:
-            images_dir = os.path.join(output_dir, topology_name + '-files',
-                                      'images')
-            os.makedirs(images_dir)
-            for image in converter.images:
-                old_image_file = os.path.abspath(image)
-                new_image_file = os.path.join(images_dir,
-                                              os.path.basename(image))
-                if os.path.isfile(os.path.abspath(old_image_file)):
-                    shutil.copy(old_image_file, new_image_file)
-                else:
-                    image_err = True
-                    logging.error('Unable to find %s' % old_image_file)
+        # Move the image files to the new topology folder
+        image_err = copy_images(converter.images, topology_files_dir)
 
-        # Create the vbox working directories if applicable
-        vbox_max = json_topology.get_vboxes()
-        if vbox_max is not None:
-            for i in range(1, vbox_max + 1):
-                vbox_dir = os.path.join(output_dir, topology_name + '-files',
-                                        'vbox', 'vm-%s' % i)
-                os.makedirs(vbox_dir)
+        # Create the vbox working directories
+        make_vbox_dirs(json_topology.get_vboxes(), output_dir, topology_name)
 
-        # Create the vbox working directories if applicable
-        qemu_max = json_topology.get_qemus()
-        if qemu_max is not None:
-            for i in range(1, qemu_max + 1):
-                qemu_dir = os.path.join(output_dir, topology_name + '-files',
-                                        'qemu', 'vm-%s' % i)
-                os.makedirs(qemu_dir)
+        # Create the qemu working directories
+        make_qemu_dirs(json_topology.get_qemus(), output_dir, topology_name)
 
         if config_err:
             logging.warning('Some router startup configurations could not be '
@@ -292,5 +267,87 @@ def save(args, converter, json_topology, snapshot):
         logging.error(error)
 
 
+def copy_configs(configs, source, target):
+    """
+    Copy dynamips configs to converted topology
+
+    :param configs: Configs to copy
+    :param str source: Source topology directory
+    :param str target: Target topology files directory
+    :return: True when a config cannot be found, otherwise false
+    :rtype: bool
+    """
+    config_err = False
+    if len(configs) > 0:
+        config_dir = os.path.join(target, 'dynamips', 'configs')
+        os.makedirs(config_dir)
+        for config in configs:
+            old_config_file = os.path.join(source, config['old'])
+            new_config_file = os.path.join(config_dir,
+                                           os.path.basename(config['new']))
+            if os.path.isfile(old_config_file):
+                # Copy and rename the config
+                shutil.copy(old_config_file, new_config_file)
+            else:
+                config_err = True
+                logging.error('Unable to find %s' % config['old'])
+    return config_err
+
+
+def copy_images(images, target):
+    """
+    Copy images to converted topology
+
+    :param images: Images to copy
+    :param target: Target topology files directory
+    :return: True when an image cannot be found, otherwise false
+    :rtype: bool
+    """
+    image_err = False
+    if len(images) > 0:
+        images_dir = os.path.join(target, 'images')
+        os.makedirs(images_dir)
+        for image in images:
+            old_image_file = os.path.abspath(image)
+            new_image_file = os.path.join(images_dir,
+                                          os.path.basename(image))
+            if os.path.isfile(os.path.abspath(old_image_file)):
+                shutil.copy(old_image_file, new_image_file)
+            else:
+                image_err = True
+                logging.error('Unable to find %s' % old_image_file)
+    return image_err
+
+
+def make_vbox_dirs(max_vbox_id, output_dir, topology_name):
+    """
+    Create VirtualBox working directories if required
+
+    :param int max_vbox_id: Number of directories to create
+    :param str output_dir: Output directory
+    :param str topology_name: Topology name
+    """
+    if max_vbox_id is not None:
+        for i in range(1, max_vbox_id + 1):
+            vbox_dir = os.path.join(output_dir, topology_name + '-files',
+                                    'vbox', 'vm-%s' % i)
+            os.makedirs(vbox_dir)
+
+
+def make_qemu_dirs(max_qemu_id, output_dir, topology_name):
+    """
+    Create Qemu VM working directories if required
+
+    :param int max_qemu_id: Number of directories to create
+    :param str output_dir: Output directory
+    :param str topology_name: Topology name
+    """
+    if max_qemu_id is not None:
+        for i in range(1, max_qemu_id + 1):
+            qemu_dir = os.path.join(output_dir, topology_name + '-files',
+                                    'qemu', 'vm-%s' % i)
+            os.makedirs(qemu_dir)
+
+
 if __name__ == '__main__':
     main()
