@@ -76,6 +76,7 @@ class Node(Interfaces):
         slot = 0
 
         for port_number in range(num_ports):
+            port_number += self.port_numbering[port_type]
             port_name = PORT_TYPES[port_type] + '%s/%s' % (slot, port_number)
             port_temp = {'name': port_name,
                          'id': self.port_id,
@@ -83,6 +84,7 @@ class Node(Interfaces):
                          'slot_number': slot}
             ports.append(port_temp)
             self.port_id += 1
+            self.port_numbering[port_type] += 1
         self.node['ports'].extend(ports)
 
     def add_slot_ports(self, slot):
@@ -456,7 +458,10 @@ class Node(Interfaces):
         # 0: Destination device 1: Destination port
         # 2: NIO 3: NIO Destination
         self.node['properties']['nios'] = []
-        self.connections = self.connections.split(' ')
+        if self.connections is None:
+            return None
+        else:
+            self.connections = self.connections.split(' ')
 
         for connection in sorted(self.connections):
             connection = connection.split(':')
